@@ -76,23 +76,23 @@ render_region_plot <- function(infile,
       check_package_dependency("rgdal", "exporting GeoTIFF files")
       raster::writeRaster(ras_col, filename = outfile, format = "GTiff")  # Requires package rgdal
     } else if (fileExtension == ".kml") {
-      kml_toolbox <- raster::rasterToPolygons(ras)
-
-      check_package_dependency("plotKML", reason = "exporting KML files")
-
-      plotKML::plotKML(
-        kml_toolbox,
-        file = outfile,
-        kmz = FALSE,
-        open.kml = FALSE,
-        plot.labpt = FALSE,
-        overwrite = TRUE,
-        outline = 0
-      )
+      # kml_toolbox <- raster::rasterToPolygons(ras)
+      # 
+      # check_package_dependency("plotKML", reason = "exporting KML files")
+      # 
+      # plotKML::plotKML(
+      #   kml_toolbox,
+      #   file = outfile,
+      #   kmz = FALSE,
+      #   open.kml = FALSE,
+      #   plot.labpt = FALSE,
+      #   overwrite = TRUE,
+      #   outline = 0
+      # )
       
-      # cat("Sorry, but the plotKML R-package was removed from CRAN 
-      #         and KML output is not possible at the moment.
-      #         We are working on a solution for the next update.","\n")
+      cat("Due to issues with the plotKML R-package we decided to remove
+              KML output from the CM SAF R Toolbox.
+              We are working on a solution for the next update.","\n")
       
     }
     return(list(
